@@ -91,7 +91,7 @@ class order:
             df = pd.read_csv('%s_profit_loss.csv' % self.account)
             print(df.to_string())
             print('\ntotal profit/loss: %s\ntotal roi: %s%%\n' % (str(
-                sum(df['pnl'])), str(round(sum(df['pnl']) / 184000 * 100, 2))))
+                sum(df['pnl'])), str(round(sum(df['pnl']) / 500000 * 100, 2))))
         else:
             print('No order found.\n')
         return
@@ -111,14 +111,14 @@ class order:
                 }
                 if ((last_trade['action'] == 'Buy').bool()):
                     position['last_price'] = bidask['ask_price'][0]
-                    position['pnl'] = ((bidask['ask_price'][0] - last_trade['price']) * 200 - last_trade['fee'] - \
+                    position['pnl'] = ((position['last_price'] - last_trade['price']) * 200 - last_trade['fee'] - \
                         last_trade['tax'] - 50 - \
-                        round(bidask['ask_price'][0] * 200 * 2 / 100000)).sum()
+                        round(position['last_price'] * 200 * 2 / 100000)).sum()
                 else:
                     position['last_price'] = bidask['bid_price'][0]
-                    position['pnl'] = ((last_trade['price'] - bidask['bid_price'][0]) * 200 - last_trade['fee'] - \
+                    position['pnl'] = ((last_trade['price'] - position['last_price']) * 200 - last_trade['fee'] - \
                         last_trade['tax'] - 50 - \
-                        round(bidask['bid_price'][0] * 200 * 2 / 100000)).sum()
+                        round(position['last_price'] * 200 * 2 / 100000)).sum()
                 return position
         else:
             return []
@@ -141,7 +141,7 @@ def update_list_profit_loss(account):
     pnl = (order['price'][-1] - order['price'][-2]) * 200 - \
         order['fee'][-1] - order['fee'][-2] - \
         order['tax'][-1] - order['tax'][-2]
-    roi = round((pnl / 184000) * 100, 2)
+    roi = round((pnl / 500000) * 100, 2)
     df = {
         'ts': order.index[-1],
         'code': order['code'][-1],
